..
      Copyright 2018 Catalyst IT Ltd
      All Rights Reserved.
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Qinling Glossary
================

As the Qinling project evolves, it's important that people working on Qinling,
users using Qinling, and operators deploying Qinling use a common set of
terminology in order to avoid misunderstandings and confusion. To that end, we
are providing the following glossary of terms.

Runtime
~~~~~~~

The runtime is programming language support. In Qinling, each runtime is
encapsulated in a container image which is used for creating the runtime
container. Qinling communicates with the container by sending HTTP requests and
runs user function inside. Currently, Qinling only supports Python 2 and
Python 3 officially and Node.JS in experimental.
